@@ -1,4 +1,4 @@
-# Copyright 2012 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2012-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -35,7 +35,7 @@ def complete_std_option_value(session, option_name, option_data, prefix=''):
     elif option_name == '--output':
         return_choices(option_data[option_name]['choices'])
     elif option_name == '--profile':
-        return_choices(session.available_profiles())
+        return_choices(session.available_profiles)
     else:
         return_no_choices()
 
